[dovecot-cvs] dovecot/src/lib-storage mail-storage-private.h, 1.1, 1.2 mail-storage.c, 1.21, 1.22 mail-storage.h, 1.64, 1.65 proxy-mailbox.c, 1.5, 1.6

cras at procontrol.fi cras at procontrol.fi
Sun May 2 23:32:18 EEST 2004


Update of /home/cvs/dovecot/src/lib-storage
In directory talvi:/tmp/cvs-serv3311/lib-storage

Modified Files:
	mail-storage-private.h mail-storage.c mail-storage.h 
	proxy-mailbox.c 
Log Message:
s/custom flags/keywords/



Index: mail-storage-private.h
===================================================================
RCS file: /home/cvs/dovecot/src/lib-storage/mail-storage-private.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- mail-storage-private.h	27 Apr 2004 20:25:54 -0000	1.1
+++ mail-storage-private.h	2 May 2004 20:32:16 -0000	1.2
@@ -59,7 +59,7 @@
 	struct mail_storage *storage;
 
 	int (*is_readonly)(struct mailbox *box);
-	int (*allow_new_custom_flags)(struct mailbox *box);
+	int (*allow_new_keywords)(struct mailbox *box);
 
 	int (*close)(struct mailbox *box);
 

Index: mail-storage.c
===================================================================
RCS file: /home/cvs/dovecot/src/lib-storage/mail-storage.c,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -d -r1.21 -r1.22
--- mail-storage.c	27 Apr 2004 20:25:54 -0000	1.21
+++ mail-storage.c	2 May 2004 20:32:16 -0000	1.22
@@ -355,9 +355,9 @@
 	return box->is_readonly(box);
 }
 
-int mailbox_allow_new_custom_flags(struct mailbox *box)
+int mailbox_allow_new_keywords(struct mailbox *box)
 {
-	return box->allow_new_custom_flags(box);
+	return box->allow_new_keywords(box);
 }
 
 int mailbox_get_status(struct mailbox *box,

Index: proxy-mailbox.c
===================================================================
RCS file: /home/cvs/dovecot/src/lib-storage/proxy-mailbox.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -d -r1.5 -r1.6
--- proxy-mailbox.c	27 Apr 2004 20:25:54 -0000	1.5
+++ proxy-mailbox.c	2 May 2004 20:32:16 -0000	1.6
@@ -11,11 +11,11 @@
 	return p->box->is_readonly(p->box);
 }
 
-static int _allow_new_custom_flags(struct mailbox *box)
+static int _allow_new_keywords(struct mailbox *box)
 {
 	struct proxy_mailbox *p = (struct proxy_mailbox *) box;
 
-	return p->box->allow_new_custom_flags(p->box);
+	return p->box->allow_new_keywords(p->box);
 }
 
 static int _close(struct mailbox *box)
@@ -111,7 +111,7 @@
 	pb->storage = box->storage;
 
 	pb->is_readonly = _is_readonly;
-	pb->allow_new_custom_flags = _allow_new_custom_flags;
+	pb->allow_new_keywords = _allow_new_keywords;
 	pb->close = _close;
 	pb->get_status = _get_status;
 	pb->sync = _sync;



More information about the dovecot-cvs mailing list
Index: mail-storage.h
===================================================================
RCS file: /home/cvs/dovecot/src/lib-storage/mail-storage.h,v
retrieving revision 1.64
retrieving revision 1.65
diff -u -d -r1.64 -r1.65
--- mail-storage.h	28 Apr 2004 00:21:00 -0000	1.64
+++ mail-storage.h	2 May 2004 20:32:16 -0000	1.65
@@ -36,7 +36,7 @@
 	STATUS_UIDVALIDITY	= 0x08,
 	STATUS_UNSEEN		= 0x10,
 	STATUS_FIRST_UNSEEN_SEQ	= 0x20,
-	STATUS_CUSTOM_FLAGS	= 0x40
+	STATUS_KEYWORDS		= 0x40
 };
 
 enum mailbox_name_status {
@@ -128,8 +128,8 @@
 	unsigned int diskspace_full:1;
 
 	/* may be allocated from data stack */
-	unsigned int custom_flags_count;
-	const char **custom_flags;
+	unsigned int keywords_count;
+	const char **keywords;
 };
 
 struct mail_storage_callbacks {
@@ -155,10 +155,10 @@
 			     unsigned int messages_count,
 			     unsigned int recent_count, void *context);
 	/* FLAGS, PERMANENTFLAGS */
-	void (*new_custom_flags)(struct mailbox *mailbox,
-				 const char *custom_flags[],
-				 unsigned int custom_flags_count,
-				 void *context);
+	void (*new_keywords)(struct mailbox *mailbox,
+			     const char *keywords[],
+			     unsigned int keywords_count,
+			     void *context);
 
 };
 
@@ -271,8 +271,8 @@
 /* Returns TRUE if mailbox is read-only. */
 int mailbox_is_readonly(struct mailbox *box);
 
-/* Returns TRUE if mailbox currently supports adding custom flags. */
-int mailbox_allow_new_custom_flags(struct mailbox *box);
+/* Returns TRUE if mailbox currently supports adding keywords. */
+int mailbox_allow_new_keywords(struct mailbox *box);
 
 /* Gets the mailbox status information. */
 int mailbox_get_status(struct mailbox *box,
